@@ -2,10 +2,8 @@
 set -eu
 
 ANSIBLE_GIT_URL=${ANSIBLE_GIT_URL:-https://github.com/ansible/ansible.git}
-# Note(TheJulia): Normally this should be stable-2.0, pinning due to
-# issues with the stable branch.
-# https://github.com/ansible/ansible-modules-core/issues/2804
-ANSIBLE_GIT_BRANCH=${ANSIBLE_GIT_BRANCH:-v2.0.0.0-1}
+ANSIBLE_GIT_BRANCH=${ANSIBLE_GIT_BRANCH:-stable-2.0}
+ANSIBLE_INSTALL_ROOT=${ANSIBLE_INSTALL_ROOT:-/opt/stack}
 
 function check_get_module () {
     local file=${1}
@@ -15,7 +13,46 @@ function check_get_module () {
     fi
 }
 
-if [ -x '/usr/bin/apt-get' ]; then
+# Check zypper before apt-get in case zypper-aptitude
+# is installed
+if [ -x '/usr/bin/zypper' ]; then
+    if ! $(python --version &>/dev/null); then
+        sudo -H zypper install -y python
+    fi
+    if ! zypper search --match-exact --installed python-devel &>/dev/null; then
+        sudo -H zypper install -y python-devel
+    fi
+    if ! $(gcc -v &>/dev/null); then
+        sudo -H zypper install -y gcc
+    fi
+    if ! $(git --version &>/dev/null); then
+        sudo -H zypper install -y git
+    fi
+    if ! $(wget --version &>/dev/null); then
+        sudo -H zypper install -y wget
+    fi
+    if [ -n "${VENV-}" ]; then
+        if $(virtualenv --version &>/dev/null); then
+            sudo -H zypper install -y python-virtualenv
+        fi
+    fi
+    if ! zypper search --match-exact --installed libopenssl-devel &>/dev/null; then
+        sudo -H zypper install -y libopenssl-devel
+    fi
+    if ! zypper search --installed libffi-devel &>/dev/null; then
+        sudo -H zypper install -y libffi-devel
+    fi
+    if ! zypper search --installed net-tools &>/dev/null; then
+        sudo -H zypper install -y net-tools
+    fi
+    if ! zypper search --match-exact --installed python-pip &>/dev/null; then
+        sudo -H zypper install -y python-pip
+    fi
+    # Make sure python-pip is the preferred one
+    if readlink -f /etc/alternatives/pip | grep -q "3."; then
+        sudo -H update-alternatives --set pip /usr/bin/pip2.*
+    fi
+elif [ -x '/usr/bin/apt-get' ]; then
     if ! $(gcc -v &>/dev/null); then
         sudo -H apt-get -y install gcc
     fi
@@ -36,8 +73,17 @@ if [ -x '/usr/bin/apt-get' ]; then
             sudo -H apt-get -y install python-virtualenv
         fi
     fi
+    if ! $(dpkg -l libssl-dev &>/dev/null); then
+        sudo -H apt-get -y install libssl-dev
+    fi
+    if ! $(dpkg -l libffi-dev &>/dev/null); then
+        sudo -H apt-get -y install libffi-dev
+    fi
+    if ! $(dpkg -l net-tools &>/dev/null); then
+        sudo -H apt-get -y install net-tools
+    fi
 elif [ -x '/usr/bin/yum' ]; then
-    if ! $(python --version $>/dev/null); then
+    if ! $(python --version &>/dev/null); then
         sudo -H yum -y install python
     fi
     if ! yum -q list installed python-devel; then
@@ -57,8 +103,17 @@ elif [ -x '/usr/bin/yum' ]; then
             sudo -H yum -y install python-virtualenv
         fi
     fi
+    if ! $(rpm -q openssl-devel &>/dev/null); then
+        sudo -H yum -y install openssl-devel
+    fi
+    if ! $(rpm -q libffi-devel &>/dev/null); then
+        sudo -H yum -y install libffi-devel
+    fi
+    if ! $(rpm -q net-tools &>/dev/null); then
+        sudo -H yum -y install net-tools
+    fi
 else
-    echo "ERROR: Supported package manager not found.  Supported: apt,yum"
+    echo "ERROR: Supported package manager not found.  Supported: apt,yum,zypper"
 fi
 
 if [ -n "${VENV-}" ]; then
@@ -105,11 +160,11 @@ sudo -H -E ${PIP} install -r "$(dirname $0)/../requirements.txt"
 u=$(whoami)
 g=$(groups | awk '{print $1}')
 
-if [ ! -d /opt/stack ]; then
-    mkdir -p /opt/stack || (sudo mkdir -p /opt/stack)
+if [ ! -d ${ANSIBLE_INSTALL_ROOT} ]; then
+    mkdir -p ${ANSIBLE_INSTALL_ROOT} || (sudo mkdir -p ${ANSIBLE_INSTALL_ROOT})
 fi
-sudo -H chown -R $u:$g /opt/stack
-cd /opt/stack
+sudo -H chown -R $u:$g ${ANSIBLE_INSTALL_ROOT}
+cd ${ANSIBLE_INSTALL_ROOT}
 
 if [ ! -d ansible ]; then
     git clone $ANSIBLE_GIT_URL --recursive -b $ANSIBLE_GIT_BRANCH
@@ -140,7 +195,7 @@ check_get_module `pwd`/lib/ansible/modules/extras/cloud/openstack/os_ironic_insp
     https://raw.githubusercontent.com/juliakreger/ansible-modules-extras/feature/os-ironic-inspect/cloud/openstack/os_ironic_inspect.py
 
 if [ -n "${VENV-}" ]; then
-    sudo -H -E ${PIP} install --upgrade /opt/stack/ansible
+    sudo -H -E ${PIP} install --upgrade ${ANSIBLE_INSTALL_ROOT}/ansible
     echo
     echo "To use bifrost, do"
 
@@ -154,6 +209,6 @@ else
     echo "following commands to update your shell."
     echo
     echo "source env-vars"
-    echo "source /opt/stack/ansible/hacking/env-setup"
+    echo "source ${ANSIBLE_INSTALL_ROOT}/ansible/hacking/env-setup"
     echo
 fi
